@@ -4,6 +4,9 @@ from .init import Module, info
 
 
 class Distro(Module):
+    '''Show infos
+    '''
+
     def deploy(self, target, **kw):
         user = 'sudo' if target.sudo else target.distro.Login.name
         os = target.OS
