@@ -2,6 +2,9 @@ from .init import Module
 
 
 class Distro(Module):
+    '''Write default SSH config
+    '''
+
     def deploy(self, target):
 
         config = '''
